@@ -1,14 +1,12 @@
 from __future__ import annotations
 
+import builtins
 import gettext
 import json
 import os
 from dataclasses import dataclass
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, override
-
-if TYPE_CHECKING:
-	_: Any
+from typing import override
 
 
 @dataclass
@@ -135,6 +133,7 @@ class TranslationHandler:
 		"""
 		Set the provided language as the current translation
 		"""
+		# The install() call has the side effect of assigning GNUTranslations.gettext to builtins._
 		language.translation.install()
 
 	def _get_locales_dir(self) -> Path:
@@ -160,40 +159,25 @@ class TranslationHandler:
 		return translation_files
 
 
-class DeferredTranslation:
+class _DeferredTranslation:
 	def __init__(self, message: str):
 		self.message = message
 
-	def __len__(self) -> int:
-		return len(self.message)
-
 	@override
 	def __str__(self) -> str:
-		translate = _
-		if translate is DeferredTranslation:
+		if builtins._ is _DeferredTranslation:  # type: ignore[attr-defined]
 			return self.message
-		return translate(self.message)
 
-	def __lt__(self, other) -> bool:
-		return self.message < other
+		# builtins._ is changed from _DeferredTranslation to GNUTranslations.gettext after
+		# Language.activate() is called
+		return builtins._(self.message)  # type: ignore[attr-defined]
 
-	def __gt__(self, other) -> bool:
-		return self.message > other
 
-	def __add__(self, other) -> DeferredTranslation:
-		if isinstance(other, str):
-			other = DeferredTranslation(other)
+def tr(message: str) -> str:
+	return str(_DeferredTranslation(message))
 
-		concat = self.message + other.message
-		return DeferredTranslation(concat)
 
-	def format(self, *args) -> str:
-		return self.message.format(*args)
-
-	@classmethod
-	def install(cls) -> None:
-		import builtins
-		builtins._ = cls  # type: ignore[attr-defined]
+builtins._ = _DeferredTranslation  # type: ignore[attr-defined]
 
 
 translation_handler = TranslationHandler()
